@@ -105,5 +105,5 @@ class BaseCrudView(BaseView):
 
     @classmethod
     def get_doc(cls, request):
-        crud = cls.schema_class({})
+        crud = cls.SCHEMA_CLASS({})
         return render(request, crud.template_path)
